@@ -19,7 +19,11 @@
  */
 
 #include <config.h>
+#ifdef GNOME_GTKHTML_EDITOR_SHLIB
+#include <glib/gi18n-lib.h>
+#else
 #include <glib/gi18n.h>
+#endif
 #include <ctype.h>
 #include <stdio.h>
 #include <string.h>
@@ -76,7 +80,7 @@ url_extract (const unsigned char **text, gboolean check)
 			return NULL;
 	}
 
-	out = g_strndup (*text, end - *text);
+	out = g_strndup ((const gchar *) *text, end - *text);
 	*text = end;
 	return out;
 }
@@ -107,7 +111,7 @@ email_address_extract (const unsigned char **cur, char **out, const unsigned cha
 	if (dot > end)
 		return NULL;
 
-	addr = g_strndup (start, end - start);
+	addr = g_strndup ((const gchar *) start, end - start);
 	*out -= *cur - start;
 	*cur = end;
 
@@ -126,7 +130,7 @@ is_citation (const unsigned char *c, gboolean saw_citation)
 	if (*c == '>') {
 		const unsigned char *p;
 
-		if (strncmp (c, ">From ", 6) != 0)
+		if (strncmp ((const gchar *) c, ">From ", 6) != 0)
 			return TRUE;
 
 		/* If the previous line was a citation, then say this
@@ -145,8 +149,8 @@ is_citation (const unsigned char *c, gboolean saw_citation)
 	}
 
 	/* Check for "Rupert> " and the like... */
-	for (i = 0; c && *c && g_unichar_validate (g_utf8_get_char (c)) && *c != '\n' && i < 10; i ++, c = g_utf8_next_char (c)) {
-		u = g_utf8_get_char (c);
+	for (i = 0; c && *c && g_unichar_validate (g_utf8_get_char ((const gchar *) c)) && (gchar) *c != '\n' && i < 10; i ++, c = (const guchar *) g_utf8_next_char (c)) {
+		u = g_utf8_get_char ((const gchar *) c);
 		if (u == '>')
 			return TRUE;
 		if (!g_unichar_isalnum (u))
@@ -219,7 +223,7 @@ e_text_to_html_full (const char *input, unsigned int flags, guint32 color)
 
 	col = 0;
 
-	for (cur = linestart = input; cur && *cur; cur = next) {
+	for (cur = linestart = (const guchar *) input; cur && *cur; cur = next) {
 		gunichar u;
 
 		if (flags & E_TEXT_TO_HTML_MARK_CITATION && col == 0) {
@@ -250,23 +254,26 @@ e_text_to_html_full (const char *input, unsigned int flags, guint32 color)
 			out += sprintf (out, "&gt; ");
 		}
 
-		u = g_utf8_get_char (cur);
+		u = g_utf8_get_char ((gchar *) cur);
 		if (g_unichar_isalpha (u) &&
 		    (flags & E_TEXT_TO_HTML_CONVERT_URLS)) {
 			char *tmpurl = NULL, *refurl = NULL, *dispurl = NULL;
 
-			if (!strncasecmp (cur, "http://", 7) ||
-			    !strncasecmp (cur, "https://", 8) ||
-			    !strncasecmp (cur, "ftp://", 6) ||
-			    !strncasecmp (cur, "nntp://", 7) ||
-			    !strncasecmp (cur, "mailto:", 7) ||
-			    !strncasecmp (cur, "news:", 5)) {
+			if (!g_ascii_strncasecmp ((gchar *) cur, "http://", 7) ||
+			    !g_ascii_strncasecmp ((gchar *) cur, "https://", 8) ||
+			    !g_ascii_strncasecmp ((gchar *) cur, "ftp://", 6) ||
+			    !g_ascii_strncasecmp ((gchar *) cur, "nntp://", 7) ||
+			    !g_ascii_strncasecmp ((gchar *) cur, "callto:", 7) ||
+			    !g_ascii_strncasecmp ((gchar *) cur, "h323:", 5) ||
+			    !g_ascii_strncasecmp ((gchar *) cur, "sip:", 4) ||
+			    !g_ascii_strncasecmp ((gchar *) cur, "mailto:", 7) ||
+			    !g_ascii_strncasecmp ((gchar *) cur, "news:", 5)) {
 				tmpurl = url_extract (&cur, TRUE);
 				if (tmpurl) {
 					refurl = e_text_to_html (tmpurl, 0);
 					dispurl = g_strdup (refurl);
 				}
-			} else if (!strncasecmp (cur, "www.", 4) &&
+			} else if (!g_ascii_strncasecmp ((gchar *) cur, "www.", 4) &&
 				   (*(cur + 4) < 0x80) &&
 				   g_unichar_isalnum (*(cur + 4))) {
 				tmpurl = url_extract (&cur, FALSE);
@@ -290,7 +297,7 @@ e_text_to_html_full (const char *input, unsigned int flags, guint32 color)
 
 			if (!*cur)
 				break;
-			u = g_utf8_get_char (cur);
+			u = g_utf8_get_char ((gchar *) cur);
 		}
 
 		if (u == '@' && (flags & E_TEXT_TO_HTML_CONVERT_ADDRESSES)) {
@@ -308,7 +315,7 @@ e_text_to_html_full (const char *input, unsigned int flags, guint32 color)
 				g_free (dispaddr);
 				g_free (outaddr);
 
-				u = g_utf8_get_char (cur);
+				u = g_utf8_get_char ((gchar *) cur);
 			}
 		}
 
@@ -319,7 +326,7 @@ e_text_to_html_full (const char *input, unsigned int flags, guint32 color)
 			u = *cur;
 			next = cur + 1;
 		} else
-			next = g_utf8_next_char (cur);
+			next = (guchar *) g_utf8_next_char (cur);
 
 		out = check_size (&buffer, &buffer_size, out, 10);
 
