@@ -33,7 +33,7 @@
 #include <glib/gi18n.h>
 #endif
 #include <string.h>
-#include <gnome.h>
+#include <gtk/gtk.h>
 #include <bonobo.h>
 #include <stdio.h>
 #include <glib.h>
@@ -42,6 +42,7 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
+#include <unistd.h>
 
 #ifndef O_BINARY
 #define O_BINARY 0
@@ -79,6 +80,7 @@
 #include "properties.h"
 #include "text.h"
 #include "paragraph.h"
+#include "paragraph-style.h"
 #include "body.h"
 #include "spellchecker.h"
 #include "html-stream-mem.h"
@@ -185,8 +187,7 @@ release (GtkWidget *widget, GdkEventButton *event, GtkHTMLControlData *cd)
 			;
 		}
 		if (run_dialog) {
-			cd->properties_dialog = gtk_html_edit_properties_dialog_new (cd, _("Properties"), 
-										     gnome_icon_theme_lookup_icon (cd->icon_theme, "stock_properties", 16, NULL, NULL));
+			cd->properties_dialog = gtk_html_edit_properties_dialog_new (cd, _("Properties"), "gtk-properties");
 			html_cursor_jump_to (e->cursor, e, cd->obj, 0);
 			html_engine_disable_selection (e);
 			html_engine_set_mark (e);
@@ -260,7 +261,7 @@ load_from_file (GtkHTML *html,
 	}
       
        	while ((len = read (fd, buffer, 4096)) > 0) {
-		gtk_html_write (html, handle, buffer, len);
+		gtk_html_write (html, handle, (gchar *) buffer, len);
 	}
 
 	if (len < 0) {
@@ -418,6 +419,7 @@ editor_set_format (GtkHTMLControlData *cd, gboolean format_html)
 
 	toolbar_update_format (cd);
 	menubar_update_format (cd);
+	paragraph_style_update_store (cd);
 
 	if (html->engine->painter != (HTMLPainter *)p) {
 		html_gdk_painter_unrealize (old_p);
@@ -546,7 +548,9 @@ editor_control_construct (BonoboControl *control, GtkWidget *vbox)
 
 	/* PropertyBag */
 	pb = bonobo_property_bag_new (editor_get_prop, editor_set_prop, cd);
-
+	/* The above causes warnings since the third arg to editor_get_prop()
+         * should be guint() according to the signature of *BonoboPropertyGetFn
+         */
 	def = bonobo_arg_new (BONOBO_ARG_BOOLEAN);
 	BONOBO_ARG_SET_BOOLEAN (def, TRUE);
 
@@ -795,7 +799,7 @@ editor_api_create_input_line (GtkHTML *html, gpointer data)
 }
 
 static void
-new_editor_api ()
+new_editor_api (void)
 {
 	editor_api = g_new (GtkHTMLEditorAPI, 1);
 
