@@ -22,23 +22,26 @@
 #ifndef _HTMLPRINTER_H
 #define _HTMLPRINTER_H
 
-#include <libgnomeprint/gnome-print.h>
-#include <libgnomeprint/gnome-print-master.h>
+#include <gtk/gtk.h>
 #include "htmlpainter.h"
 
-
 #define HTML_TYPE_PRINTER                 (html_printer_get_type ())
-#define HTML_PRINTER(obj)                 (GTK_CHECK_CAST ((obj), HTML_TYPE_PRINTER, HTMLPrinter))
-#define HTML_PRINTER_CLASS(klass)         (GTK_CHECK_CLASS_CAST ((klass), HTML_TYPE_PRINTER, HTMLPrinterClass))
-#define HTML_IS_PRINTER(obj)              (GTK_CHECK_TYPE ((obj), HTML_TYPE_PRINTER))
-#define HTML_IS_PRINTER_CLASS(klass)      (GTK_CHECK_CLASS_TYPE ((klass), HTML_TYPE_PRINTER))
+#define HTML_PRINTER(obj)                 (G_TYPE_CHECK_INSTANCE_CAST((obj), HTML_TYPE_PRINTER, HTMLPrinter))
+#define HTML_PRINTER_CLASS(klass)         (G_TYPE_CHECK_CLASS_CAST ((klass), HTML_TYPE_PRINTER, HTMLPrinterClass))
+#define HTML_IS_PRINTER(obj)              (G_TYPE_CHECK_INSTANCE_TYPE ((obj), HTML_TYPE_PRINTER))
+#define HTML_IS_PRINTER_CLASS(klass)      (G_TYPE_CHECK_CLASS_TYPE ((klass), HTML_TYPE_PRINTER))
+
+/* The following macros are used to convert between the HTMLEngine coordinate
+   system (which uses integers) to the GnomePrint one (which uses doubles). */
+
+#define SCALE_ENGINE_TO_GNOME_PRINT(x) ((printer->scale * (x)) / 1024.0)
+#define SCALE_GNOME_PRINT_TO_ENGINE(x) ((gint) (((x) * 1024.0 / printer->scale) + 0.5))
+#define SCALE_PANGO_TO_GNOME_PRINT(x) (((x)) / 1024.0)
 
-
 struct _HTMLPrinter {
 	HTMLPainter base;
 
-	GnomePrintContext *print_context;
-	GnomePrintMaster  *print_master;
+	GtkPrintContext *context;
 	gdouble scale;
 };
 
@@ -46,10 +49,9 @@ struct _HTMLPrinterClass {
 	HTMLPainterClass base;
 };
 
-
 GtkType      html_printer_get_type                    (void);
-HTMLPainter *html_printer_new                         (GnomePrintContext *print_context,
-						       GnomePrintMaster  *print_master);
+HTMLPainter *html_printer_new                         (GtkWidget         *widget,
+						       GtkPrintContext *context);
 guint        html_printer_get_page_width              (HTMLPrinter       *printer);
 guint        html_printer_get_page_height             (HTMLPrinter       *printer);
 gdouble      html_printer_scale_to_gnome_print        (HTMLPrinter       *printer,
@@ -59,5 +61,7 @@ void         html_printer_coordinates_to_gnome_print  (HTMLPrinter       *printe
 						       gint               engine_y,
 						       gdouble           *print_x_return,
 						       gdouble           *print_y_return);
+void         html_printer_set_scale                   (HTMLPrinter       *printer,
+						       gdouble            scale);
 
 #endif /* _HTMLPRINTER_H */
